.. include:: ../README.rst

Contents
========

.. toctree::
    :maxdepth: 3

    installation/index
    changes
    development/index
    api/index
    authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

